@@ -1922,7 +1922,7 @@ void infile(char *ifname, char *idelim)
   char *fname;
   static char *delim;
   static int delimlen;
-
+  
   if (!infinit)
     {
       infinit = 1;
@@ -1930,6 +1930,7 @@ void infile(char *ifname, char *idelim)
       delim = dap_malloc(delimlen + 1, "infile: delim");
       fieldwd = (int *) dap_malloc(sizeof(int) * dap_maxvar, "infile: fieldwd");
     }
+    
   if (dap_in[dap_ono])
     {
       dfclose(dap_in[dap_ono]);
@@ -1964,6 +1965,7 @@ void infile(char *ifname, char *idelim)
 	  exit(1);
 	}
     }
+    
   /* the 'f' says that it's not a dataset, so don't need to prepend directory */
   if (!(dap_in[dap_ono] = dfopen(fname, "rf")))
     {
@@ -1979,12 +1981,16 @@ void infile(char *ifname, char *idelim)
 	;
     }
   dap_delim = delim[0];
+    
   for (nfields = 0, d = 1; delim[d]; nfields++)
     {
+	    
       if (nfields < dap_maxvar)
 	{
 	  for (fieldwd[nfields] = 0; delim[d] && delim[d] != dap_delim; )
+	  {
 	    fieldwd[nfields] = 10 * fieldwd[nfields] + delim[d++] - '0';
+	  }
 	  if (delim[d])
 	    d++;
 	}
@@ -1994,10 +2000,12 @@ void infile(char *ifname, char *idelim)
 	  exit(1);
 	}
     }
+    
   v = dap_clearobs((char *) NULL);
   strcpy(dap_obs[dap_ono].do_str[v], "OBS");
   lineno[dap_ono] = 1;
   toolong = 0;
+    
 }
 
 void input(char varlist[])
@@ -2976,3 +2984,312 @@ void dap_head(int markv[], int nmark)
     }
   putc('\n', dap_lst);
 }
+
+typedef struct CharList CharList;
+struct CharList {
+   char * word;
+   CharList *next;
+};
+
+
+#define DOUBLER 1
+#define STRINGER 0
+
+typedef struct AttributeList AttributeList;
+struct AttributeList {
+   char * word;
+   int size;
+   int type;
+   AttributeList *next;
+};
+
+
+
+/**
+Max 50000 words
+*/
+CharList extractWords(char * buffer, long size,char  *delimiter)
+{
+	char * bufferWord= (char*) malloc (sizeof(char)*size+1);
+	memset (bufferWord,'\0',size+1);
+	CharList list;
+	list.word=NULL;
+	list.next=NULL;
+	CharList *current=&list;
+	long i=0l;
+	long sSize=0l;
+	long sIndex=0l;
+	for(i=0l;i<size;i++)
+	{
+		if (buffer[i]=='\r' || buffer[i]=='\t')
+			continue;
+		if (buffer[i]==delimiter[0])
+		{
+			current->word= (char*) malloc (sizeof(char)*sIndex+5);
+			strcpy(current->word,bufferWord);
+			current->next= (char*) malloc (sizeof(CharList));
+			current=current->next;
+			sSize=sIndex;
+			sIndex=0;
+			memset (bufferWord,'\0',size+1);
+		}
+		else
+		{
+			bufferWord[sIndex]=buffer[i];
+			sIndex++;
+		}
+		
+	}
+	if (sIndex>0)
+	{
+		current->word= (char*) malloc ((sizeof(char)*strlen(bufferWord))+1);
+		strcpy(current->word,bufferWord);
+		current->next= NULL;
+	}
+	free(bufferWord);
+		
+	return list;
+}
+
+void cleanAttributeList( AttributeList *list)
+{
+	AttributeList *actualatt=list;
+	do{
+		actualatt=list;
+		AttributeList *prev=list;
+		AttributeList *prev2=list;
+		do{
+			prev2=prev;
+			prev=actualatt;
+			actualatt=actualatt->next;
+		}while(actualatt!=NULL);
+		if (prev!=list){
+			free(prev->word);
+			free(prev);
+		}
+		prev2->next=NULL;
+	}while(list->next!=NULL);
+}
+
+void cleanCharList( CharList *list)
+{
+	CharList *actualatt=list;
+	do{
+		actualatt=list;
+		CharList *prev=list;
+		CharList *prev2=list;
+		do{
+			prev2=prev;
+			prev=actualatt;
+			actualatt=actualatt->next;
+		}while(actualatt!=NULL);
+		if (prev!=list)
+		{
+			free(prev->word);
+			free(prev);
+		}
+		prev2->next=NULL;
+	}while(list->next!=NULL);
+}
+
+
+
+int import(char* fname,  char* fileToLoad, char * format, char  *delimiter,int replace,int getnames){
+	
+	infile(fileToLoad,delimiter);
+	FILE * pFile;
+	long lSize;
+	char * buffer;
+	char * bufferline;
+	size_t result;
+	if (strcmp(format,"CSV")&&strcmp(format,"DLM")&&strcmp(format,"csv")&&strcmp(format,"dlm")
+		&&strcmp(format,"TAB")&&strcmp(format,"tab"))
+	{
+		printf ("Format not supported :%s\n",format); exit (1);
+	}
+	if (strlen(delimiter)==0)
+	{
+		if(strcmp(format,"CSV")||strcmp(format,"csv"))
+			delimiter=",";
+		if(strcmp(format,"DLM")||strcmp(format,"dlm"))
+			delimiter=" ";
+		if(strcmp(format,"TAB")||strcmp(format,"tab"))
+			delimiter="\t";
+	}
+	pFile = fopen (fileToLoad , "rb" );
+	if (pFile==NULL) {
+		printf ("File loading error :%s\n",fileToLoad); exit (1);
+	}
+	// obtain file size:
+	fseek (pFile , 0 , SEEK_END);
+	lSize = ftell (pFile);
+	rewind (pFile);
+	// allocate memory to contain the whole file:
+	buffer = (char*) malloc (sizeof(char)*lSize);
+	if (buffer == NULL) {printf ("Memory error \n"); exit (2);}
+	bufferline = (char*) malloc (sizeof(char)*lSize);
+	if (bufferline == NULL) {printf ("2nd Memory error \n"); exit (2);}
+
+	// copy the file into the buffer:
+	result = fread (buffer,1,lSize,pFile);
+	if (result != lSize) {printf ("Reading error \n"); exit (3);}
+
+	long sIndex=0l;
+	long sSize=0l;
+	long i=0l;
+	
+	AttributeList listatt;
+	listatt.word=NULL;
+	listatt.next=NULL;
+	 //the whole file is now loaded in the memory buffer. 
+	int lineCnt=0;
+	for(i=0l;i<lSize;i++)
+	{
+		
+		if (buffer[i] == '\n')
+		{
+			CharList list=extractWords(bufferline,sIndex,  delimiter);
+			CharList *actual=&list;
+			int counter=0;
+			do{
+				char *word=actual->word;
+				int sizeStr=strlen(word);
+				AttributeList *actualatt=&listatt;
+				AttributeList *prev=actualatt;
+				
+				if(lineCnt==0)
+				{
+					
+					
+					if (actualatt->word==NULL)
+					{
+						if(getnames)
+						{
+							actualatt->word= (char*) malloc (sizeof(char)*strlen(word)+5);
+							strcpy(actualatt->word,word);
+						}
+						else
+						{
+							actualatt->word= (char*) malloc (sizeof(char)*10);
+							sprintf(actualatt->word,"X%d",counter);
+						}	
+					}
+					else
+					{
+						do{
+							char *wordatt=actualatt->word;
+							if (strcmp(wordatt,word)==0)
+							{
+								break;
+							}
+							prev=actualatt;
+							actualatt=actualatt->next;
+						}while(actualatt!=NULL);
+						if (actualatt==NULL)
+						{
+							prev->next=(AttributeList*) malloc (sizeof(AttributeList));
+							prev->next->word=NULL;
+							prev=prev->next;
+							if(getnames)
+							{
+								prev->word= (char*) malloc (sizeof(char)*strlen(word)+5);
+								strcpy(prev->word,word);
+							}
+							else
+							{
+								prev->word= (char*) malloc (sizeof(char)*10);
+								sprintf(prev->word,"X%d",counter);
+							}
+							prev->next=NULL;
+							
+						}
+					}
+				}
+				actualatt=&listatt;
+				prev=actualatt;
+				if((getnames&&lineCnt>0)||!getnames)
+				{
+					
+					int counterbis=0;
+					do{
+						if (counter==counterbis)
+							break;
+						actualatt=actualatt->next;
+						counterbis++;
+					}while(actualatt!=NULL);
+					if (actualatt!=NULL)
+					{
+						//measure column size
+						if (sizeStr>actualatt->size)
+							actualatt->size=sizeStr;
+						if (actualatt->size>1000)
+							actualatt->size=1000;
+						float f;
+						if(sscanf(word, "%f", &f) != 0)
+							actualatt->type=DOUBLER;
+						else
+							actualatt->type=STRINGER;
+					}
+					
+				}
+				actual=actual->next;
+				counter++;
+			}while(actual!=NULL);
+			sSize=sIndex;
+			sIndex=0;
+			lineCnt++;
+			cleanCharList(&list);
+		}
+		else
+		{
+			bufferline[sIndex]=buffer[i];
+			sIndex++;
+		}
+		
+	}
+	// terminate
+	fclose (pFile);
+	free (buffer);
+	free (bufferline);
+	AttributeList *actualatt=&listatt;
+	int countcol=0;
+	
+	do{
+		char *wordatt=actualatt->word;
+		if(wordatt!=NULL)
+		{
+
+			int sierr=strlen(wordatt)+6;
+			char *bufferer= (char*) malloc (sizeof(char)*sierr);
+			
+			
+			if(actualatt->type==DOUBLER)
+			{
+				sprintf(bufferer,"%s -1",wordatt);
+				dap_vd(bufferer, -1);
+				
+			}
+			else
+			{
+				int size=1000;
+				if (actualatt->size<1000)
+					size=actualatt->size;
+				sprintf(bufferer,"%s %d",wordatt,actualatt->size);
+				dap_vd(bufferer,size);
+				
+			
+			}
+		}
+		countcol++;
+		actualatt=actualatt->next;
+	}while(actualatt!=NULL);
+	
+	outset(fname, "");
+	skip(2);
+        while (step())
+          output();
+
+	cleanAttributeList(&listatt);
+	
+	return 0;
+}
