@@ -1264,6 +1264,8 @@ void proctrans(char *step, FILE *dapfile)
     regtrans(step + 9, dapfile);
   else if (!linecmp(step + 5, "dap"))
     daptrans(step + 9, dapfile);
+   else if (!linecmp(step + 5, "import"))
+    importtrans(step + 9, dapfile);
   else
     {
       for (s = 5; step[s] && step[s] != '\n'; s++)
