@@ -18,6 +18,8 @@
 
 #include <stdio.h>
 #include "sbs.h"
+#include <stdlib.h>
+#include <string.h>
 
 extern char sbstmp[TOKENLEN + 1]; /* name of current temp dataset */
 extern int sbslineno;
