@@ -685,3 +685,55 @@ void daptrans(char *step, FILE *dapfile)
       fputs(";\n", dapfile);
     }
 }
+
+
+/* import call to DAP. step starts after "proc import" */
+void importtrans(char *step, FILE *dapfile)
+{
+  int s; /* index to step */
+  int brace; /* level of braces nesting */
+  int start; /* starting position */
+  int resplen; /* length of response variable name */
+  int replace=0;
+  static char delimiter[TOKENLEN + 1];
+  static char setname[TOKENLEN + 1];
+  static char datafile[TOKENLEN + 1];
+  static char dbms[TOKENLEN + 1];
+  static char strreplace[TOKENLEN + 1];
+  static char getnames[4];
+	
+  if (!getoption(step, "out", setname, 1))
+    strcpy(setname, sbstmp);
+  if (!getoption(step, "datafile", datafile, 1))
+    strcpy(datafile, sbstmp);
+  if (!getoption(step, "dbms", dbms, 1))
+    strcpy(dbms, sbstmp);
+  if (!getoption(step, "delimiter", delimiter, 1))
+    strcpy(delimiter, "");
+  else{
+	if(delimiter[0]=='\'')
+		delimiter[0]='"';
+	if(delimiter[strlen(delimiter)-1]=='\'')
+		delimiter[strlen(delimiter)-1]='"';
+}
+   
+   if ((s = findstatement(step, "getnames")))
+   {
+	int i=8;
+	while(step[s+i]!='n'&&step[s+i]!='y'&&step[s+i]!=';'&&step[s+i]!='\0')
+		i++;
+	if (step[s+i]=='n'||step[s+i]=='N')
+		strcpy(getnames, "no");
+	else
+		strcpy(getnames, "yes");
+   }
+
+  int getnam=1;
+  if(strcmp(getnames,"no")==0)
+	  getnam=0;
+  if (!getoption(step, "replace", strreplace, 0))
+    replace=1;
+  /* we have to sort by the class vars and to get means, etc. */
+  fprintf(dapfile, "import(\"%s\", %s , \"%s\",%s, %i,%i);\n", setname,datafile,dbms,delimiter,replace,getnam);
+  
+}
\ No newline at end of file
